@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%% @author Evgeny Khramtsov <ekhramtsov@process-one.net>
-%%% @copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
+%%% @copyright (C) 2002-2025 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -756,6 +756,11 @@ generate_key(ec) ->
 generate_key(rsa) ->
     public_key:generate_key({rsa, 2048, 65537}).
 
+%% OTP-28.0-rc4 in commit b230e26c4f6530563919b19e76f2d2e96e436048
+%% removed in the file lib/public_key/asn1/PKCS-10.asn1
+%% several definitions. Let's add manually the macro here:
+-define('p1_acme-pkcs-9-at-extensionRequest', {1,2,840,113549,1,9,14}).
+
 -spec generate_csr([domain(), ...], priv_key()) -> #'CertificationRequest'{}.
 generate_csr([_|_] = Domains, PrivKey) ->
     SignAlgoOID = signature_algorithm(PrivKey),
@@ -769,7 +774,7 @@ generate_csr([_|_] = Domains, PrivKey) ->
 			  critical = false,
 			  extnValue = DerSAN}],
     DerExtnReq = public_key:der_encode('ExtensionRequest', Extns),
-    Attribute = #'AttributePKCS-10'{type = ?'pkcs-9-at-extensionRequest',
+    Attribute = #'AttributePKCS-10'{type = ?'p1_acme-pkcs-9-at-extensionRequest',
 				    values = [{asn1_OPENTYPE, DerExtnReq}]},
     SubjPKInfo = #'CertificationRequestInfo_subjectPKInfo'{
 		    subjectPublicKey = subject_pubkey(PubKey),
@@ -913,7 +918,7 @@ jose_json(#state{account = {Key, AccURL}, nonce = Nonce} = State, Data, URL) ->
     JwsMap = case AccURL of
 		 undefined ->
 		     {_, BinaryPubKey} = jose_jwk:to_binary(PubKey),
-		     PubKeyJson = json_decode_list(BinaryPubKey),
+		     PubKeyJson = json_decode_maps(BinaryPubKey),
 		     JwsMap0#{<<"jwk">> => PubKeyJson};
 		 _ ->
 		     JwsMap0#{<<"kid">> => iolist_to_binary(AccURL)}
@@ -937,15 +942,11 @@ json_encode(Term) ->
     iolist_to_binary(jiffy:encode(Term)).
 json_decode_maps(Bin) ->
     jiffy:decode(Bin, [return_maps]).
-json_decode_list(Bin) ->
-    jiffy:decode(Bin).
 -else.
 json_encode(Term) ->
     iolist_to_binary(json:encode(Term)).
 json_decode_maps(Bin) ->
     json:decode(Bin).
-json_decode_list(Bin) ->
-    maps:to_list(json:decode(Bin)).
 -endif.
 
 %%%===================================================================
